translate.storage.fpo.pofile

Package translate :: Package storage :: Module fpo :: Class pofile |
[hide private]
[frames] | no frames]

# Class pofile

source code

A .po file containing various units

Nested Classes | [hide private]
| UnitClass The class of units that will be instantiated and used by this class

Instance Methods | [hide private]
__init__(self, inputfile=None, encoding=None, unitclass=pounit) Construct a pofile, optionally reading in from inputfile. | source code
changeencoding(self, newencoding) Deprecated: changes the encoding on the file. | source code
_build_self_from_cpo(self) Builds up this store from the internal cpo store. | source code
_build_cpo_from_self(self) Builds the internal cpo store from the data in self. | source code
parse(self, input) Parses the given file or file source string. | source code
removeduplicates(self, duplicatestyle="merge") Make sure each msgid is unique ; merge comments etc from duplicates into original | source code
__str__(self) Convert to a string. | source code
Inherited from `poheader.poheader`: `getheaderplural`, `gettargetlanguage`, `header`, `makeheader`, `makeheaderdict`, `mergeheaders`, `parseheader`, `settargetlanguage`, `updatecontributor`, `updateheader`, `updateheaderplural` Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `findid`, `findunit`, `findunits`, `getsourcelanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setsourcelanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
Inherited from `pocommon.pofile`: `Extensions`, `Mimetypes`, `Name` Inherited from `poheader.poheader`: `header_order`, `x_generator` Inherited from `base.TranslationStore`: `suggestions_in_format` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, encoding=None, unitclass=pounit) (Constructor) | source code
Construct a pofile, optionally reading in from inputfile. encoding can be specified but otherwise will be read from the PO header Overrides: object.__init__

### _build_self_from_cpo(self) | source code
Builds up this store from the internal cpo store. A user must ensure that self._cpo_store already exists, and that it is deleted afterwards.

### _build_cpo_from_self(self) | source code
Builds the internal cpo store from the data in self. A user must ensure that self._cpo_store does not exist, and should delete it after using it.

### parse(self, input) | source code
Parses the given file or file source string. Overrides: base.TranslationStore.parse

### __str__(self) (Informal representation operator) | source code
Convert to a string. double check that unicode is handled somehow here Overrides: object.__str__